@@ -15,6 +15,7 @@ mod selector;
 mod node;
 mod cakeclient;
 mod failmode;
+mod config;
 
 pub use crate::endpoint::{
   serve, Ack, Client, Endpoint, Response,
@@ -44,6 +45,10 @@ pub use crate::cakeclient::{
   CakeClient,
 };
 
+pub use crate::config::{
+  CONFIG,
+};
+
 pub use rmpv::{Integer, Utf8String, Value};
 
 // todo: global extern test module
