@@ -17,16 +17,16 @@ fn test_struct_to_vec() {
   let cat = Animal{
     name: "cat".to_string()
   };
-  log::trace!("cat -------- {:?}", cat);
+  log::trace!("cat -->>> {:?}", cat);
 
   // struct to vec
   let stu = serde_json::to_vec(&cat);
   match stu {
     Ok(stu) => {
-      log::trace!("stu -------- {:?}", stu);
+      log::trace!("stu -->>> {:?}", stu);
       // vec to struct
       let catx = serde_json::from_slice::<Animal>(&stu);
-      log::trace!("catx ------------ {:?}", catx);
+      log::trace!("catx -->>> {:?}", catx);
     }
     Err(err) => { log::trace!("err ------------- {:?}", err); }
   }
